@@ -26,8 +26,10 @@ from euphorie.ghost import PathGhost
 from json import dumps
 from logging import getLogger
 from os import path
+from pkg_resources import resource_listdir
 from plone import api
 from plone.i18n.normalizer import idnormalizer
+from plone.memoize import forever
 from plone.memoize.instance import memoize
 from plone.memoize.view import memoize_contextless
 from plonetheme.nuplone.utils import isAnonymous
@@ -55,21 +57,22 @@ logger = getLogger(__name__)
 
 # XXX should to to config (registry?)
 NAME_TO_PHASE = {
-    'start': 'preparation',
-    'profile': 'preparation',
-    'identification': 'identification',
-    'customization': 'identification',
-    'actionplan': 'actionplan',
-    'report': 'report',
-    'status': 'status',
-    'help': 'help',
-    'new-email': 'useraction',
-    'account-settings': 'useraction',
-    'account-delete': 'useraction',
-    'update': 'preparation',
-    'disclaimer': 'help',
-    'terms-and-conditions': 'help',
-    'training': 'training',
+    "start": "preparation",
+    "involve": "involve",
+    "profile": "preparation",
+    "identification": "identification",
+    "customization": "identification",
+    "actionplan": "actionplan",
+    "report": "report",
+    "status": "status",
+    "help": "help",
+    "new-email": "useraction",
+    "account-settings": "useraction",
+    "account-delete": "useraction",
+    "update": "preparation",
+    "disclaimer": "help",
+    "terms-and-conditions": "help",
+    "training": "training",
 }
 
 
@@ -82,15 +85,21 @@ class WebHelpers(BrowserView):
 
     View name: @@webhelpers
     """
+
     certificates_path = "++resource++euphorie.resources/oira/certificates"
     media_path = "++resource++euphorie.resources/media"
     style_path = "++resource++euphorie.resources/oira/style"
+    script_path = "++resource++euphorie.resources/oira/script"
 
-    css_path = "++resource++euphorie.resources/oira/style/all.css"
-    css_path_min = "++resource++euphorie.resources/oira/style/all.css"
+    brand = "oira"
 
-    js_path = "++resource++euphorie.resources/oira/script/bundle.js"
-    js_path_min = "++resource++euphorie.resources/oira/script/bundle.min.js"
+    css_path = "++resource++euphorie.resources/{brand}/style/all.css"
+    css_path_min = "++resource++euphorie.resources/{brand}/style/all.css"
+
+    js_name = "bundle.js"
+    js_name_min = "bundle.min.js"
+
+    favicon_path = "++resource++euphorie.resources/{brand}/favicon/apple-touch-icon.png"
 
     group_model = Group
     survey_session_model = SurveySession
@@ -123,37 +132,47 @@ class WebHelpers(BrowserView):
     @memoize
     def _settings(self):
         appconfig = getUtility(IAppConfig)
-        return appconfig.get('euphorie')
+        return appconfig.get("euphorie")
 
     @property
     @memoize
     def allow_social_sharing(self):
-        return asBool(self._settings.get('allow_social_sharing', False))
+        return asBool(self._settings.get("allow_social_sharing", False))
 
     @property
     @memoize
     def allow_guest_accounts(self):
-        return asBool(self._settings.get('allow_guest_accounts', False))
+        return asBool(self._settings.get("allow_guest_accounts", False))
+
+    @property
+    @memoize
+    def use_involve_phase(self):
+        return asBool(self._settings.get("use_involve_phase", False))
 
     @property
     @memoize
     def use_training_module(self):
-        return asBool(self._settings.get('use_training_module', False))
+        return asBool(self._settings.get("use_training_module", False))
 
     @property
     @memoize
     def use_publication_feature(self):
-        return asBool(self._settings.get('use_publication_feature', False))
+        return asBool(self._settings.get("use_publication_feature", False))
 
     @property
     @memoize
     def use_clone_feature(self):
-        return asBool(self._settings.get('use_clone_feature', False))
+        return asBool(self._settings.get("use_clone_feature", False))
 
     @property
     @memoize
     def use_archive_feature(self):
-        return asBool(self._settings.get('use_archive_feature', False))
+        return asBool(self._settings.get("use_archive_feature", False))
+
+    @property
+    @memoize
+    def use_help_section(self):
+        return api.portal.get_registry_record("euphorie.use_help_section", default=True)
 
     @property
     @memoize
@@ -164,7 +183,7 @@ class WebHelpers(BrowserView):
     @property
     @memoize
     def default_country(self):
-        return self._settings.get('default_country', '')
+        return self._settings.get("default_country", "")
 
     @property
     @memoize
@@ -179,7 +198,7 @@ class WebHelpers(BrowserView):
     @property
     @memoize
     def is_guest_account(self):
-        account = getattr(self._user, 'account_type', None)
+        account = getattr(self._user, "account_type", None)
         return account == config.GUEST_ACCOUNT
 
     @property
@@ -224,16 +243,15 @@ class WebHelpers(BrowserView):
             Session.query(SurveyTreeItem)
             .filter(SurveyTreeItem.session_id == session.id)
             .filter(SurveyTreeItem.type == "module")
-            .filter(SurveyTreeItem.skip_children == False)
+            .filter(SurveyTreeItem.skip_children == False)  # noqa: E712
         ).order_by(SurveyTreeItem.depth)
         total_risks = 0
         answered_risks = 0
 
         @memoize
         def recursive_skip_children(module):
-            return (
-                module.skip_children
-                or (module.parent and recursive_skip_children(module.parent))
+            return module.skip_children or (
+                module.parent and recursive_skip_children(module.parent)
             )
 
         for module in query:
@@ -249,15 +267,15 @@ class WebHelpers(BrowserView):
                 .filter(Risk.depth == module.depth + 1)
             )
             total_risks = total_risks + total_risks_query.count()
-            answered_risks_query = (
-                total_risks_query
-                .filter(Risk.identification != None)
+            answered_risks_query = total_risks_query.filter(
+                Risk.identification != None  # noqa: E711
             )
             answered_risks = answered_risks + answered_risks_query.count()
 
         completion_percentage = (
-            int(round((answered_risks * 1. / total_risks * 1.) * 100.))
-            if total_risks else 0
+            int(round((answered_risks * 1.0 / total_risks * 1.0) * 100.0))
+            if total_risks
+            else 0
         )
         session.completion_percentage = completion_percentage
         return completion_percentage
@@ -289,6 +307,13 @@ class WebHelpers(BrowserView):
             if IClientCountry.providedBy(obj):
                 return obj
 
+    @property
+    @memoize
+    def county_obj_via_parents(self):
+        for obj in self.request.PARENTS:
+            if IClientCountry.providedBy(obj):
+                return obj
+
     @property
     @memoize
     def country_name(self):
@@ -300,13 +325,22 @@ class WebHelpers(BrowserView):
     @property
     @memoize
     def content_country_obj(self):
-        """Return the country object from the content area.
-        """
+        """Return the country object from the content area."""
         country_id = self.country_obj.id
         root = getUtility(ISiteRoot)
         country = getattr(root.sectors, country_id)
         return country
 
+    @property
+    @memoize
+    def selected_country(self):
+        """Return the country id that is present in the path. Fall back to the
+        default_country"""
+        country = self.county_obj_via_parents
+        if country:
+            return country.getId()
+        return self.default_country
+
     @property
     @memoize
     def sector_name(self):
@@ -319,7 +353,7 @@ class WebHelpers(BrowserView):
     def tool_name(self):
         obj = self._survey
         if not obj:
-            return ''
+            return ""
         return obj.Title()
 
     @property
@@ -327,27 +361,42 @@ class WebHelpers(BrowserView):
     def tool_description(self):
         obj = self._survey
         if not obj:
-            return ''
-        ploneview = self.context.restrictedTraverse('@@plone')
+            return ""
+        ploneview = self.context.restrictedTraverse("@@plone")
         return ploneview.cropText(StripMarkup(obj.introduction), 800)
 
     @property
     @memoize
     def language_code(self):
-        lt = getToolByName(self.context, 'portal_languages')
+        lt = getToolByName(self.context, "portal_languages")
         lang = lt.getPreferredLanguage()
         return lang
 
+    @property
+    @forever.memoize
+    def available_help_languages(self):
+        exclude = set(["illustrations"])
+        return set(resource_listdir("euphorie.client", "resources/oira/help")) - exclude
+
+    @property
+    @memoize
+    def help_language(self):
+        lang = self.language_code
+        # No country-specific Help texts are curently supported
+        if lang.find("-"):
+            lang = lang.split("-")[0]
+        return lang if lang in self.available_help_languages else "en"
+
     def get_username(self):
         member = api.user.get_current()
-        return member.getProperty('fullname') or member.getUserName()
+        return member.getProperty("fullname") or member.getUserName()
 
     def get_webstats_js(self):
-        return api.portal.get_registry_record('plone.webstats_js')
+        return api.portal.get_registry_record("plone.webstats_js")
 
     def language_dict(self):
         site = getSite()
-        ltool = getToolByName(site, 'portal_languages')
+        ltool = getToolByName(site, "portal_languages")
         return ltool.getAvailableLanguages()
 
     @property
@@ -357,34 +406,33 @@ class WebHelpers(BrowserView):
     @property
     @memoize
     def country(self):
-        """ XXX it would be better to write this country id, consider deprecating this
-        """
+        """XXX it would be better to write this country id, consider deprecating this"""
         obj = self.country_obj
         if not obj:
             return ""
         return obj.id
 
     def logoMode(self):
-        return 'alien' if 'alien' in self.extra_css else 'native'
+        return "alien" if "alien" in self.extra_css else "native"
 
     @property
     @memoize
     def extra_css(self):
         sector = self.sector
         if sector is None:
-            return u''
+            return u""
 
         sector = aq_base(sector)
         parts = []
 
-        if getattr(sector, 'logo', None) is not None:
-            parts.append('alien')
+        if getattr(sector, "logo", None) is not None:
+            parts.append("alien")
 
-        lt = getToolByName(self.context, 'portal_languages')
+        lt = getToolByName(self.context, "portal_languages")
         lang = lt.getPreferredLanguage()
-        parts.append('language-%s' % lang)
+        parts.append("language-%s" % lang)
 
-        return ' ' + ' '.join(parts)
+        return " " + " ".join(parts)
 
     @property
     @memoize
@@ -393,18 +441,19 @@ class WebHelpers(BrowserView):
         context is not in a sector return the agency name instead.
         """
         sector = self.sector
-        if sector is not None and \
-                getattr(aq_base(sector), 'logo', None) is not None:
+        if sector is not None and getattr(aq_base(sector), "logo", None) is not None:
             return sector.Title()
         else:
             return _(
-                'title_tool',
-                default=u'OiRA - Online interactive Risk Assessment',
+                "title_tool",
+                default=u"OiRA - Online interactive Risk Assessment",
             )
 
     @property
     @memoize
     def client(self):
+        if not self.context:
+            return
         for obj in self.context.aq_chain:
             if IClient.providedBy(obj):
                 return obj
@@ -413,7 +462,12 @@ class WebHelpers(BrowserView):
     @memoize
     def client_url(self):
         """Return the absolute URL for the client."""
-        return self.client.absolute_url() if self.client else '.'
+        return self.client.absolute_url() if self.client else "."
+
+    @property
+    @memoize
+    def portal_url(self):
+        return api.portal.get().absolute_url()
 
     @property
     @memoize
@@ -429,8 +483,9 @@ class WebHelpers(BrowserView):
         the country will be used as parent.
         """
         base_url = self.survey_url()
-        if base_url is not None and \
-                aq_inner(self.context).absolute_url().startswith(base_url):
+        if base_url is not None and aq_inner(self.context).absolute_url().startswith(
+            base_url
+        ):
             return base_url
         base_url = self.country_url
         if base_url is not None:
@@ -450,50 +505,60 @@ class WebHelpers(BrowserView):
     @property
     @memoize
     def certificates_url(self):
-        return "{}/{}".format(
-            self.client_url, self.certificates_path)
+        return "{}/{}".format(self.client_url, self.certificates_path)
 
     @property
     @memoize
     def media_url(self):
-        return "{}/{}".format(
-            self.client_url, self.media_path)
+        return "{}/{}".format(self.client_url, self.media_path)
 
     @property
     @memoize
     def style_url(self):
-        return "{}/{}".format(
-            self.client_url, self.style_path)
+        return "{}/{}".format(self.client_url, self.style_path)
 
     @property
     @memoize
     def css_url(self):
         return "{}/{}?t={}".format(
             self.client_url,
-            self.css_path if not self.debug_mode else self.css_path_min,
-            self.resources_timestamp
+            self.css_path.format(brand=self.brand)
+            if not self.debug_mode
+            else self.css_path_min.format(brand=self.brand),
+            self.resources_timestamp,
         )
 
     @property
     @memoize
     def js_url(self):
+        return "{}/{}/{}?t={}".format(
+            self.client_url,
+            self.script_path,
+            self.js_name if not self.debug_mode else self.js_name_min,
+            self.resources_timestamp,
+        )
+
+    @property
+    @memoize
+    def favicon_url(self):
         return "{}/{}?t={}".format(
             self.client_url,
-            self.js_path if not self.debug_mode else self.js_path_min,
-            self.resources_timestamp
+            self.favicon_path.format(brand=self.brand),
+            self.resources_timestamp,
         )
 
     @property
     @memoize
     @deprecate(
-        "Replace with  a check for `webhelpers.survey_url`, deprecated in version 11.1.2"
+        "Replace with  a check for `webhelpers.survey_url`, "
+        "deprecated in version 11.1.2"
     )
     def is_outside_of_survey(self):
         if self._base_url() != self.survey_url():
             return True
         if (
-            self.request.get('ACTUAL_URL').split('/')[-1] ==
-            self.survey_url().split('/')[-1]
+            self.request.get("ACTUAL_URL").split("/")[-1]
+            == self.survey_url().split("/")[-1]
         ):
             return True
         return False
@@ -504,17 +569,16 @@ class WebHelpers(BrowserView):
         survey = self._survey
         if not survey:
             return None
-        if (
-            getattr(self, 'session', None) and
-            "/".join(survey.getPhysicalPath()).endswith(self.session.zodb_path)
-        ):
+        if getattr(self, "session", None) and "/".join(
+            survey.getPhysicalPath()
+        ).endswith(self.session.zodb_path):
             return self.session.title
         return survey.title
 
     def get_phase(self):
         head, tail = path.split(self.request.PATH_INFO)
         while tail:
-            tail = tail.replace('@', '').split("_")[0]
+            tail = tail.replace("@", "").split("_")[0]
             if tail in NAME_TO_PHASE:
                 return NAME_TO_PHASE[tail]
             head, tail = path.split(head)
@@ -538,7 +602,7 @@ class WebHelpers(BrowserView):
         """Return the URL to the current online help page. If we are in a
         survey the help page will be located there. Otherwise the country
         will be used as parent."""
-        return '%s/help' % self._base_url()
+        return "%s/help" % self._base_url()
 
     @property
     @memoize
@@ -546,14 +610,14 @@ class WebHelpers(BrowserView):
         """Return the URL to the current online about page. If we are in a
         survey the help page will be located there. Otherwise the country
         will be used as parent."""
-        return '%s/about' % self._base_url()
+        return "%s/about" % self._base_url()
 
     @property
     @memoize
     def authenticated(self):
         """Check if the current user is authenticated."""
         user = getSecurityManager().getUser()
-        return user is not None and user.getUserName() != 'Anonymous User'
+        return user is not None and user.getUserName() != "Anonymous User"
 
     @property
     @memoize
@@ -604,39 +668,54 @@ class WebHelpers(BrowserView):
 
         url = survey.absolute_url()
         if phase is not None:
-            url += '/@@%s' % phase
+            url += "/@@%s" % phase
         return url
 
     @memoize
     def survey_zodb_path(self):
         """
-            Construct zodb_path from current survey.
-            Helper method, since I don't always trust self.session.zodb_path
+        Construct zodb_path from current survey.
+        Helper method, since I don't always trust self.session.zodb_path
         """
         elems = []
         obj = self._survey
+        if not obj:
+            return ""
         while not IClient.providedBy(obj):
             elems.append(obj.id)
             obj = aq_parent(obj)
         elems.reverse()
         return "/".join(elems)
 
+    @property
+    @memoize
+    def integrated_action_plan(self):
+        if not asBool(self._settings.get("use_integrated_action_plan", False)):
+            return False
+        return getattr(self._survey, "integrated_action_plan", False)
+
     @property
     @memoize
     def in_session(self):
         """Check if there is an active survey session."""
         return self._survey is not None
 
+    def is_initialised_session(self, session):
+        """
+        A session without children has not passed the Identification phase yet
+        """
+        return session.children().count()
+
     @property
     @memoize
     def appendix_documents(self):
         """Return a list of items to be shown in the appendix."""
         documents = api.portal.get().documents
 
-        lt = getToolByName(self.context, 'portal_languages')
+        lt = getToolByName(self.context, "portal_languages")
         lang = lt.getPreferredLanguage()
-        if '-' in lang:
-            languages = [lang, lang.split('-')[0]]
+        if "-" in lang:
+            languages = [lang, lang.split("-")[0]]
         else:
             languages = [lang]
 
@@ -644,16 +723,17 @@ class WebHelpers(BrowserView):
             docs = documents.get(lang, None)
             if docs is None:
                 continue
-            appendix = docs.get('appendix', None)
+            appendix = docs.get("appendix", None)
             if appendix is not None:
                 break
         else:
             return []
 
         base_url = self._base_url()
-        return [{'url': '%s/appendix/%s' % (base_url, page.id),
-                 'title': page.Title()}
-                for page in appendix.values()]
+        return [
+            {"url": "%s/appendix/%s" % (base_url, page.id), "title": page.Title()}
+            for page in appendix.values()
+        ]
 
     @property
     @memoize
@@ -661,12 +741,12 @@ class WebHelpers(BrowserView):
         """Check if the current request is from an iPhone or similar device
         (such as an iPod touch).
         """
-        agent = self.request.get_header('User-Agent', '')
-        return 'iPhone' in agent
+        agent = self.request.get_header("User-Agent", "")
+        return "iPhone" in agent
 
-    def months(self, length='wide'):
-        calendar = self.request.locale.dates.calendars['gregorian']
-        months = calendar.monthContexts['format'].months[length]
+    def months(self, length="wide"):
+        calendar = self.request.locale.dates.calendars["gregorian"]
+        months = calendar.monthContexts["format"].months[length]
         return sorted(months.items())
 
     def timezoned_date(self, mydate=None):
@@ -720,10 +800,12 @@ class WebHelpers(BrowserView):
         if motd:
             now = datetime.now()
             message = dict(
-                title=StripMarkup(motd.description), text=motd.body,
-                id='motd{0}{1}'.format(
-                    motd.modification_date.strftime('%Y%m%d%H%M%S'),
-                    now.strftime('%Y%m%d'))
+                title=StripMarkup(motd.description),
+                text=motd.body,
+                id="motd{0}{1}".format(
+                    motd.modification_date.strftime("%Y%m%d%H%M%S"),
+                    now.strftime("%Y%m%d"),
+                ),
             )
         return message
 
@@ -737,10 +819,12 @@ class WebHelpers(BrowserView):
             message = dict(
                 title=obj.tool_notification_title,
                 text=obj.tool_notification_message,
-                id='tool{}{}{}'.format(
-                    obj.modification_date.strftime('%Y%m%d%H%M%S'),
-                    now.strftime('%Y%m%d'),
-                    ''.join(obj.getPhysicalPath()[2:])))
+                id="tool{}{}{}".format(
+                    obj.modification_date.strftime("%Y%m%d%H%M%S"),
+                    now.strftime("%Y%m%d"),
+                    "".join(obj.getPhysicalPath()[2:]),
+                ),
+            )
         return message
 
     def closetext(self):
@@ -763,7 +847,7 @@ class WebHelpers(BrowserView):
 
     @memoize
     def get_session_group_id(self):
-        return getattr(self.session, 'group_id', '')
+        return getattr(self.session, "group_id", "")
 
     @property
     @memoize
@@ -777,9 +861,7 @@ class WebHelpers(BrowserView):
     @property
     @memoize
     def can_edit_session(self):
-        return (
-            self.can_view_session and not self.traversed_session.session.is_archived
-        )
+        return self.can_view_session and not self.traversed_session.session.is_archived
 
     @property
     @memoize
@@ -803,8 +885,7 @@ class WebHelpers(BrowserView):
     @property
     @memoize
     def is_owner(self):
-        ''' Check if the current user is the owner of the session
-        '''
+        """Check if the current user is the owner of the session"""
         session = self.traversed_session.session
         return self.get_current_account() == session.account
 
@@ -814,23 +895,26 @@ class WebHelpers(BrowserView):
         return self.use_clone_feature
 
     def resume(self, session):
-        ''' Resume a session for the current user if he is allowed to
-        '''
+        """Resume a session for the current user if he is allowed to"""
         raise Exception("Obsolete, we traverse to sessions now")
 
     def as_md(self, text):
-        """ Return a text with Carriage Returns formatted as a Markdown.
-        """
-        return u"\r\n".join([x for x in text.split('\r')])
+        """Return a text with Carriage Returns formatted as a Markdown."""
+        return u"\r\n".join([x for x in text.split("\r")])
 
     def show_logo(self):
-        """ In plain Euphorie, the logo is always shown
-        """
+        """In plain Euphorie, the logo is always shown"""
         return True
 
+    @property
+    @memoize
+    def custom_js(self):
+        """Return custom JavaScript where necessary"""
+        return ""
+
     @memoize_contextless
     def date_picker_i18n_json(self):
-        """ Taken from:
+        """Taken from:
         https://github.com/ploneintranet/ploneintranet/blob/master/src/ploneintranet/layout/browser/date_picker.py  # noqa: E501
 
         Use this like:
@@ -898,7 +982,7 @@ class WebHelpers(BrowserView):
         filter_by_group=False,
         table=None,
     ):
-        """ Method to return a query that looks for sessions
+        """Method to return a query that looks for sessions
 
         :param context: limits the sessions under this context
         :param searchable_text: filters on survey title
