@@ -44,10 +44,10 @@ class Resume(grok.View):
     grok.name("resume")
 
     def render(self):
-        """ We always open the tool on the "Start" page.
-            Formerly, we would jump to the first question. Since the Start
-            page is now much more important, it is also used when a session
-            gets resumed.
+        """We always open the tool on the "Start" page.
+        Formerly, we would jump to the first question. Since the Start
+        page is now much more important, it is also used when a session
+        gets resumed.
         """
         survey = aq_inner(self.context)
         if self.webhelpers.redirectOnSurveyUpdate():
@@ -131,8 +131,7 @@ class _StatusHelper(object):
             path = path[3:]
 
     def getModulePaths(self):
-        """ Return a list of all the top-level modules belonging to this survey.
-        """
+        """Return a list of all the top-level modules belonging to this survey."""
         session_id = self.session.id
         if not session_id:
             return []
@@ -156,8 +155,8 @@ class _StatusHelper(object):
         return module_paths
 
     def getModules(self):
-        """ Return a list of dicts of all the top-level modules and locations
-            belonging to this survey.
+        """Return a list of dicts of all the top-level modules and locations
+        belonging to this survey.
         """
         sql_session = self.sql_session
         session_id = self.session.id
@@ -232,8 +231,8 @@ class _StatusHelper(object):
         return modules
 
     def getRisks(self, module_paths, skip_unanswered=False):
-        """ Return a list of risk dicts for risks that belong to the modules
-            with paths as specified in module_paths.
+        """Return a list of risk dicts for risks that belong to the modules
+        with paths as specified in module_paths.
         """
         global request
         request = self.request
