@@ -17,24 +17,20 @@ def createSurvey():
     session = Session()
     account = model.Account(loginname=u"jane", password=u"secret")
     session.add(account)
-    survey = model.SurveySession(
-        title=u"Session", zodb_path="survey", account=account
-    )
+    survey = model.SurveySession(title=u"Session", zodb_path="survey", account=account)
     session.add(survey)
     session.flush()
     return (session, survey)
 
 
 class SurveySessionTests(EuphorieIntegrationTestCase):
-
     def test_iface(self):
-        ''' SurveySessions are marked by the ISurveySession interface
-        '''
+        """SurveySessions are marked by the ISurveySession interface"""
         survey = createSurvey()[-1]
         self.assertTrue(model.ISurveySession.providedBy(survey))
 
     def test_is_archived(self):
-        """ Verify that a session is archived when the archived attribute
+        """Verify that a session is archived when the archived attribute
         is set and it is in the past
         """
         session = model.SurveySession()
@@ -52,35 +48,31 @@ class SurveySessionTests(EuphorieIntegrationTestCase):
         eusector = api.content.create(
             type="euphorie.clientsector", id="eusector", container=eu
         )
-        api.content.create(
-            type="euphorie.survey", id="eusurvey", container=eusector
-        )
+        api.content.create(type="euphorie.survey", id="eusurvey", container=eusector)
         nl = api.content.create(
             type="euphorie.clientcountry", id="nl", container=self.portal.client
         )
         nlsector = api.content.create(
             type="euphorie.clientsector", id="nlsector", container=nl
         )
-        api.content.create(
-            type="euphorie.survey", id="nlsurvey", container=nlsector
-        )
+        api.content.create(type="euphorie.survey", id="nlsurvey", container=nlsector)
 
         context_filter = model.SurveySession.get_context_filter(self.portal)
         self.assertSetEqual(
             {clause.value for clause in context_filter.right.element.clauses},
-            {u'eu/eusector/eusurvey', u'nl/nlsector/nlsurvey'}
+            {u"eu/eusector/eusurvey", u"nl/nlsector/nlsurvey"},
         )
 
         context_filter = model.SurveySession.get_context_filter(self.portal.client)
         self.assertSetEqual(
             {clause.value for clause in context_filter.right.element.clauses},
-            {u'eu/eusector/eusurvey', u'nl/nlsector/nlsurvey'}
+            {u"eu/eusector/eusurvey", u"nl/nlsector/nlsurvey"},
         )
 
         context_filter = model.SurveySession.get_context_filter(self.portal.client.eu)
         self.assertSetEqual(
             {clause.value for clause in context_filter.right.element.clauses},
-            {u'eu/eusector/eusurvey'}
+            {u"eu/eusector/eusurvey"},
         )
 
         context_filter = model.SurveySession.get_context_filter(self.portal.sectors)
@@ -101,9 +93,7 @@ class SurveySessionTests(EuphorieIntegrationTestCase):
             model.Module(title=u"Root", module_id="1", zodb_path="1")
         )
         ses.add(root)
-        root.addChild(
-            model.Module(title=u"Module", module_id="1", zodb_path="1/1")
-        )
+        root.addChild(model.Module(title=u"Module", module_id="1", zodb_path="1/1"))
         ses.flush()
         self.assertEqual(root.children().count(), 1)
 
@@ -114,24 +104,18 @@ class SurveySessionTests(EuphorieIntegrationTestCase):
         )
         ses.add(root)
         ses.flush()
-        root.addChild(
-            model.Module(title=u"Profile 5", module_id="5", zodb_path="1/5")
-        )
-        root.addChild(
-            model.Module(title=u"Profile 1", module_id="1", zodb_path="1/1")
-        )
-        root.addChild(
-            model.Module(title=u"Profile 3", module_id="3", zodb_path="1/3")
-        )
+        root.addChild(model.Module(title=u"Profile 5", module_id="5", zodb_path="1/5"))
+        root.addChild(model.Module(title=u"Profile 1", module_id="1", zodb_path="1/1"))
+        root.addChild(model.Module(title=u"Profile 3", module_id="3", zodb_path="1/3"))
         ses.flush()
-        self.assertEqual([c.module_id for c in list(root.children())],
-                         [u"5", "1", "3"])
+        self.assertEqual([c.module_id for c in list(root.children())], [u"5", "1", "3"])
 
     def testReset_NoChildren(self):
         (ses, survey) = createSurvey()
         survey.reset()
-        children = ses.query(model.SurveyTreeItem.id
-                             ).filter(model.SurveyTreeItem.session == survey)
+        children = ses.query(model.SurveyTreeItem.id).filter(
+            model.SurveyTreeItem.session == survey
+        )
         self.assertEqual(children.count(), 0)
 
     def testReset_SingleChild(self):
@@ -140,8 +124,9 @@ class SurveySessionTests(EuphorieIntegrationTestCase):
             model.Module(title=u"Root", module_id="1", zodb_path="1")
         )
         ses.add(root)
-        children = ses.query(model.SurveyTreeItem.id
-                             ).filter(model.SurveyTreeItem.session == survey)
+        children = ses.query(model.SurveyTreeItem.id).filter(
+            model.SurveyTreeItem.session == survey
+        )
         self.assertEqual(children.count(), 1)
         survey.reset()
         self.assertEqual(children.count(), 0)
@@ -160,14 +145,10 @@ class SurveySessionTests(EuphorieIntegrationTestCase):
 
 
 class RiskPresentFilterTests(EuphorieIntegrationTestCase):
-
     def createData(self):
         (self.session, self.survey) = createSurvey()
         self.mod1 = model.Module(
-            title=u"Module 1",
-            module_id="1",
-            zodb_path="1",
-            skip_children=False
+            title=u"Module 1", module_id="1", zodb_path="1", skip_children=False
         )
         self.survey.addChild(self.mod1)
         self.q1 = model.Risk(
@@ -175,7 +156,7 @@ class RiskPresentFilterTests(EuphorieIntegrationTestCase):
             risk_id="1",
             zodb_path="1/1",
             type="risk",
-            identification="no"
+            identification="no",
         )
         self.mod1.addChild(self.q1)
 
@@ -200,14 +181,10 @@ class RiskPresentFilterTests(EuphorieIntegrationTestCase):
 
 
 class RiskPresentNoTop5FilterTests(EuphorieIntegrationTestCase):
-
     def createData(self):
         (self.session, self.survey) = createSurvey()
         self.mod1 = model.Module(
-            title=u"Module 1",
-            module_id="1",
-            zodb_path="1",
-            skip_children=False
+            title=u"Module 1", module_id="1", zodb_path="1", skip_children=False
         )
         self.survey.addChild(self.mod1)
         self.q1 = model.Risk(
@@ -215,13 +192,14 @@ class RiskPresentNoTop5FilterTests(EuphorieIntegrationTestCase):
             risk_id="1",
             zodb_path="1/1",
             type="risk",
-            identification="no"
+            identification="no",
         )
         self.mod1.addChild(self.q1)
 
     def query(self):
-        return self.session.query(model.SurveyTreeItem)\
-                .filter(model.RISK_PRESENT_NO_TOP5_NO_POLICY_DO_EVALUTE_FILTER)
+        return self.session.query(model.SurveyTreeItem).filter(
+            model.RISK_PRESENT_NO_TOP5_NO_POLICY_DO_EVALUTE_FILTER
+        )
 
     def testValidRisk(self):
         self.createData()
@@ -244,14 +222,10 @@ class RiskPresentNoTop5FilterTests(EuphorieIntegrationTestCase):
 
 
 class ModuleWithRiskFilterTests(EuphorieIntegrationTestCase):
-
     def createData(self):
         (self.session, self.survey) = createSurvey()
         self.mod1 = model.Module(
-            title=u"Module 1",
-            module_id="1",
-            zodb_path="1",
-            skip_children=False
+            title=u"Module 1", module_id="1", zodb_path="1", skip_children=False
         )
         self.survey.addChild(self.mod1)
         self.q1 = model.Risk(
@@ -259,13 +233,14 @@ class ModuleWithRiskFilterTests(EuphorieIntegrationTestCase):
             risk_id="1",
             zodb_path="1/1",
             type="risk",
-            identification="no"
+            identification="no",
         )
         self.mod1.addChild(self.q1)
 
     def query(self):
-        return self.session.query(model.SurveyTreeItem)\
-                .filter(model.MODULE_WITH_RISK_FILTER)
+        return self.session.query(model.SurveyTreeItem).filter(
+            model.MODULE_WITH_RISK_FILTER
+        )
 
     def testValidModule(self):
         self.createData()
@@ -285,24 +260,20 @@ class ModuleWithRiskFilterTests(EuphorieIntegrationTestCase):
         (self.session, self.survey) = createSurvey()
         self.session.add(self.survey)
         self.mod1 = model.Module(
-            title=u"Module 1",
-            module_id="1",
-            zodb_path="1",
-            skip_children=False
+            title=u"Module 1", module_id="1", zodb_path="1", skip_children=False
         )
         self.survey.addChild(self.mod1)
         self.assertEqual(self.query().count(), 0)
 
 
 class AccountTests(DatabaseTests):
-
     def testGlobalRoles(self):
         user = model.Account()
-        self.assertEqual(user.getRoles(), ("EuphorieUser", ))
+        self.assertEqual(user.getRoles(), ("EuphorieUser",))
 
     def testRolesInContext(self):
         user = model.Account()
-        self.assertEqual(user.getRolesInContext(None), ("EuphorieUser", ))
+        self.assertEqual(user.getRolesInContext(None), ("EuphorieUser",))
 
     def testNoViewPermission(self):
         user = model.Account()
@@ -310,15 +281,11 @@ class AccountTests(DatabaseTests):
 
     def testHasSurveyViewPermission(self):
         user = model.Account()
-        self.assertEqual(
-            user.has_permission("Euphorie: View a Survey", None), True
-        )
+        self.assertEqual(user.has_permission("Euphorie: View a Survey", None), True)
 
     def testNonLicetLoviNonLicetBovi(self):
         user = model.Account()
-        self.assertEqual(
-            user.allowed(None, _what_not_even_god_should_do), False
-        )
+        self.assertEqual(user.allowed(None, _what_not_even_god_should_do), False)
 
     def testHasAnonymousRole(self):
         user = model.Account()
@@ -346,23 +313,23 @@ class AccountTests(DatabaseTests):
         account.account_type = config.CONVERTED_ACCOUNT
         self.session.flush()  # check that exception is not raised
         self.assertEqual(account.account_type, config.CONVERTED_ACCOUNT)
-        account.account_type = 'invalid'
+        account.account_type = "invalid"
         self.assertRaises(StatementError, self.session.flush)
 
     def testGroups(self):
         session = Session()
-        group1 = model.Group(group_id='1')
+        group1 = model.Group(group_id="1")
         session.add(group1)
         session.flush()
-        self.assertEqual(group1.group_id, '1')
+        self.assertEqual(group1.group_id, "1")
         # Verify that a group might have one parent but many children
-        group2 = model.Group(group_id='2')
+        group2 = model.Group(group_id="2")
         session.add(group2)
-        group3 = model.Group(group_id='3')
+        group3 = model.Group(group_id="3")
         session.add(group3)
         group3.parent = group2.parent = group1
         session.flush()
-        self.assertEqual(group2.group_id, '2')
+        self.assertEqual(group2.group_id, "2")
         self.assertEqual(group2.parent, group1)
         self.assertEqual(group1.parent, None)
         self.assertListEqual(group1.children, [group2, group3])
@@ -370,12 +337,12 @@ class AccountTests(DatabaseTests):
 
     def testAccountGroupsRelationship(self):
         session = Session()
-        group1 = model.Group(group_id='1')
+        group1 = model.Group(group_id="1")
         session.add(group1)
         session.flush()
-        account1 = model.Account(loginname='account1')
+        account1 = model.Account(loginname="account1")
         session.add(account1)
-        account2 = model.Account(loginname='account2')
+        account2 = model.Account(loginname="account2")
         session.add(account2)
         session.flush()
         self.assertEqual(account1.group, None)
@@ -385,28 +352,28 @@ class AccountTests(DatabaseTests):
 
     def testAccountGroupsHierarchy(self):
         session = Session()
-        group1 = model.Group(group_id='1')
+        group1 = model.Group(group_id="1")
         session.add(group1)
-        group2 = model.Group(group_id='2')
+        group2 = model.Group(group_id="2")
         group2.parent = group1
         session.add(group2)
-        group3 = model.Group(group_id='3')
+        group3 = model.Group(group_id="3")
         session.add(group3)
         group3.parent = group1
-        group4 = model.Group(group_id='4')
+        group4 = model.Group(group_id="4")
         session.add(group3)
         group4.parent = group2
         session.flush()
-        account1 = model.Account(loginname='account1')
+        account1 = model.Account(loginname="account1")
         session.add(account1)
         account1.group = group1
-        account2 = model.Account(loginname='account2')
+        account2 = model.Account(loginname="account2")
         session.add(account2)
         account2.group = group2
-        account3 = model.Account(loginname='account3')
+        account3 = model.Account(loginname="account3")
         session.add(account3)
         account3.group = group3
-        account4 = model.Account(loginname='account4')
+        account4 = model.Account(loginname="account4")
         session.add(account4)
         session.flush()
         self.assertListEqual(group1.descendants, [group2, group3, group4])
@@ -423,21 +390,22 @@ class AccountTests(DatabaseTests):
 
     def testSessions(self):
         session = Session()
-        group1 = model.Group(group_id='1')
+        group1 = model.Group(group_id="1")
         session.add(group1)
-        group2 = model.Group(group_id='2')
+        group2 = model.Group(group_id="2")
         session.add(group2)
-        account1 = model.Account(loginname='account1')
+        account1 = model.Account(loginname="account1")
         session.add(account1)
         account1.group = group1
         group2.parent = group1
         from functools import partial
+
         add_survey = partial(model.SurveySession, account=account1)
-        survey1 = add_survey(zodb_path='1')
+        survey1 = add_survey(zodb_path="1")
         session.add(survey1)
-        survey2 = add_survey(zodb_path='2', group=group1)
+        survey2 = add_survey(zodb_path="2", group=group1)
         session.add(survey2)
-        survey3 = add_survey(zodb_path='3', group=group2)
+        survey3 = add_survey(zodb_path="3", group=group2)
         session.add(survey3)
         session.flush()
         self.assertListEqual(account1.sessions, [survey1, survey2, survey3])
@@ -445,31 +413,31 @@ class AccountTests(DatabaseTests):
         self.assertListEqual(group2.sessions, [survey3])
 
     def testSessionAcquisition(self):
-        ''' Users belonging to a group should be able to see all the sessions
+        """Users belonging to a group should be able to see all the sessions
         belonging to the group and the group children
-        '''
+        """
         session = Session()
-        group1 = model.Group(group_id='1')
+        group1 = model.Group(group_id="1")
         session.add(group1)
-        group2 = model.Group(group_id='2')
+        group2 = model.Group(group_id="2")
         session.add(group2)
-        account1 = model.Account(loginname='account1')
+        account1 = model.Account(loginname="account1")
         session.add(account1)
         account1.group = group1
         group2.parent = group1
-        account2 = model.Account(loginname='account2')
+        account2 = model.Account(loginname="account2")
         session.add(account2)
         account2.group = group2
         survey1 = model.SurveySession(
             account=account1,
             group=group1,
-            zodb_path='1',
+            zodb_path="1",
         )
         session.add(survey1)
         survey2 = model.SurveySession(
             account=account2,
             group=group2,
-            zodb_path='2',
+            zodb_path="2",
         )
         session.add(survey2)
         session.flush()
@@ -480,7 +448,6 @@ class AccountTests(DatabaseTests):
 
 
 class SurveySessionDBTests(DatabaseTests):
-
     def test_get_account_filter(self):
         session = model.SurveySession()
         account = model.Account(id=1)
