@@ -11,23 +11,26 @@ the standard description field with a rich text version, and registers
 a catalog indexer which returns a plain text version of the description.
 """
 
-import HTMLParser
-from zope import schema
-from plone.indexer import indexer
-from plone.directives import form
 from euphorie.content import MessageFactory as _
 from euphorie.content.utils import StripMarkup
 from plone.app.z3cform.wysiwyg import WysiwygFieldWidget
+from plone.directives import form
+from plone.indexer import indexer
+from zope import schema
+
+import HTMLParser
 
 
 class IRichDescription(form.Schema):
     """Simple behaviour for content types with a HTML description.
     Replaces the standard description field with a rich text version.
     """
+
     description = schema.Text(
-            title = _(u"Summary"),
-            description = _(u'A short summary of the content.'),
-            required = False)
+        title=_(u"Summary"),
+        description=_(u"A short summary of the content."),
+        required=False,
+    )
     form.widget(description=WysiwygFieldWidget)
     form.order_after(description="title")
 
