@@ -1,9 +1,9 @@
-from zope.interface import Interface
+from OFS.event import ObjectClonedEvent
+from OFS.interfaces import IObjectClonedEvent
 from zope.component.interfaces import IObjectEvent
 from zope.component.interfaces import ObjectEvent
-from OFS.interfaces import IObjectClonedEvent
-from OFS.event import ObjectClonedEvent
 from zope.interface import implements
+from zope.interface import Interface
 
 
 class IObjectPublishedEvent(IObjectClonedEvent):
@@ -12,6 +12,7 @@ class IObjectPublishedEvent(IObjectClonedEvent):
 
 class ObjectPublishedEvent(ObjectClonedEvent):
     """An object has been published by copying it to the client area."""
+
     implements(IObjectPublishedEvent)
 
 
@@ -21,6 +22,7 @@ class ISurveyUnpublishEvent(IObjectEvent):
 
 class SurveyUnpublishEvent(ObjectEvent):
     """A survey is being removed from the client."""
+
     implements(ISurveyUnpublishEvent)
 
 
@@ -29,3 +31,8 @@ class IQuestionContainer(Interface):
     not for risks.
     """
 
+
+class ICustomRisksModule(Interface):
+    """Marker interface to mark a module specifically designated for adding
+    custom risks.
+    """
