@@ -8,18 +8,18 @@ A standard Solution that a user can select for a particular risk.
 
 from .. import MessageFactory as _
 from euphorie.content import utils
-# from euphorie.content.utils import IToolTypesInfo
 from five import grok
+from plone.dexterity.content import Item
 from plone.directives import dexterity
 from plone.directives import form
 from plone.indexer import indexer
 from plonetheme.nuplone.skin.interfaces import NuPloneSkin
-# from z3c.appconfig.interfaces import IAppConfig
 from zope import schema
-# from zope.component import getUtility
 from zope.i18n import translate
 from zope.interface import implements
 
+import markdown
+
 
 grok.templatedir("templates")
 
@@ -36,71 +36,75 @@ class ISolution(form.Schema):
         description=_(
             "help_module_description",
             default=u"Include any relevant information that may be "
-            u"helpful for the end-user."
+            u"helpful for the end-user.",
         ),
-        required=True
+        required=True,
     )
     form.order_after(description="title")
 
     action_plan = schema.Text(
         title=_(
             "label_measure_action_plan",
-            default=u"General approach (to eliminate or reduce the risk)"
+            default=u"General approach (to eliminate or reduce the risk)",
         ),
         description=_(
             "help_measure_action_plan",
             default=u"Describe your general approach to eliminate or (if "
-            u"the risk is not avoidable) reduce the risk."
+            u"the risk is not avoidable) reduce the risk.",
         ),
-        required=False
+        required=False,
     )
 
     prevention_plan = schema.Text(
         title=_(
             "label_measure_prevention_plan",
-            default=u"Specific action(s) required to implement this "
-            u"approach"
+            default=u"Specific action(s) required to implement this " u"approach",
         ),
         description=_(
             "help_measure_prevention_plan",
             default=u"Describe the specific action(s) required to "
-            u"implement this approach (to eliminate or to reduce the risk)."
+            u"implement this approach (to eliminate or to reduce the risk).",
         ),
-        required=False
+        required=False,
     )
 
     # This replaces action_plan and prevention_plan by concatenating the 2 fields.
     action = schema.Text(
         title=_(
             "label_measure_action",
-            default=u"General approach (to eliminate or reduce the risk) + Specific action(s) "
-            u"required to implement this approach"
+            default=(
+                u"General approach (to eliminate or reduce the risk) + "
+                u"Specific action(s) required to implement this approach"
+            ),
         ),
         description=_(
             "help_measure_action",
-            default=u"Describe your general approach to eliminate or (if the risk is not avoidable) "
-            u"reduce the risk. + Describe the specific action(s) required to implement this approach "
-            u"(to eliminate or to reduce the risk)."
+            default=(
+                u"Describe your general approach to eliminate or "
+                u"(if the risk is not avoidable) "
+                u"reduce the risk. + Describe the specific action(s) "
+                u"required to implement this approach "
+                u"(to eliminate or to reduce the risk)."
+            ),
         ),
         required=True,
-
     )
 
     requirements = schema.Text(
         title=_(
             "label_measure_requirements",
-            default=u"Level of expertise and/or requirements needed"
+            default=u"Level of expertise and/or requirements needed",
         ),
         description=_(
             "help_measure_requirements",
-            default=u'Describe the level of expertise needed to implement '
+            default=u"Describe the level of expertise needed to implement "
             u'the measure, for instance "common sense (no OSH knowledge '
             u'required)", "no specific OSH expertise, but minimum OSH '
-            u'knowledge or training and/or consultation of OSH guidance '
+            u"knowledge or training and/or consultation of OSH guidance "
             u'required", or "OSH expert". You can also describe here '
-            u'any other additional requirement (if any).'
+            u"any other additional requirement (if any).",
         ),
-        required=False
+        required=False,
     )
 
     # show_in_identification = schema.Bool(
@@ -118,41 +122,46 @@ class ISolution(form.Schema):
     # )
 
 
-class Solution(dexterity.Item):
+class Solution(Item):
     implements(ISolution)
     title = _("title_common_solution", default=u"Measure")
     prevention_plan = None
     requirements = None
-    portal_type = 'euphorie.solution'
+    portal_type = "euphorie.solution"
 
     def Title(self):
         survey = utils.getSurvey(self)
         return translate(
-            Solution.title,
-            context=self.REQUEST,
-            target_language=survey.language
-        ).encode('utf-8')
+            Solution.title, context=self.REQUEST, target_language=survey.language
+        ).encode("utf-8")
 
 
 @indexer(ISolution)
 def SearchableTextIndexer(obj):
-    """ Index the problem_description, question and solution_direction
-    """
-    return " ".join([
-        obj.description, obj.action_plan or '', obj.prevention_plan or '',
-        obj.requirements or '', obj.action or ''
-    ])
+    """Index the problem_description, question and solution_direction"""
+    return " ".join(
+        [
+            obj.description,
+            obj.action_plan or "",
+            obj.prevention_plan or "",
+            obj.requirements or "",
+            obj.action or "",
+        ]
+    )
 
 
 class View(grok.View):
-    """ View name: @@nuplone-view
-    """
+    """View name: @@nuplone-view"""
+
     grok.context(ISolution)
     grok.require("zope2.View")
     grok.layer(NuPloneSkin)
     grok.name("nuplone-view")
     grok.template("solution_view")
 
+    def render_md(self, text):
+        return markdown.markdown(text)
+
 
 class Add(dexterity.AddForm):
     grok.context(ISolution)
