@@ -1,3 +1,4 @@
+# coding=utf-8
 """
 Survey
 ======
@@ -31,6 +32,7 @@ from htmllaundry.z3cform import HtmlText
 from OFS.event import ObjectClonedEvent
 from plone.app.dexterity.behaviors.metadata import IBasic
 from plone.app.z3cform.wysiwyg import WysiwygFieldWidget
+from plone.dexterity.content import Container
 from plone.directives import dexterity
 from plone.directives import form
 from plone.indexer import indexer
@@ -40,6 +42,7 @@ from plonetheme.nuplone.z3cform.directives import depends
 from Products.CMFCore.utils import getToolByName
 from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
 from Products.statusmessages.interfaces import IStatusMessage
+from z3c.appconfig.interfaces import IAppConfig
 from ZODB.POSException import ConflictError
 from zope import schema
 from zope.component import getMultiAdapter
@@ -59,94 +62,139 @@ class ISurvey(form.Schema, IBasic):
 
     The survey is the root of a survey.
     """
+
     title = schema.TextLine(
-            title=_("label_survey_title", default=u"Version name"),
-            description=_("help_survey_title",
-                default=u"This is the title of this OiRA Tool version. This "
-                        u"name is never shown to users."),
-            required=True)
+        title=_("label_survey_title", default=u"Version name"),
+        description=_(
+            "help_survey_title",
+            default=u"This is the title of this OiRA Tool version. This "
+            u"name is never shown to users.",
+        ),
+        required=True,
+    )
     form.order_before(title="*")
 
     form.omitted("description")
 
     introduction = HtmlText(
-            title=_("label_introduction", default=u"Introduction text"),
-            description=_(u"The introduction text is shown when starting a new "
-                    u"OiRA Tool session. If no introduction is provided here a "
-                    u"standard text will be shown. Please keep this text brief "
-                    u"so it will easily fit on screens of small devices such as "
-                    u"phones and PDAs."),
-            required=False)
+        title=_("label_introduction", default=u"Introduction text"),
+        description=_(
+            u"The introduction text is shown when starting a new "
+            u"OiRA Tool session. If no introduction is provided here a "
+            u"standard text will be shown. Please keep this text brief "
+            u"so it will easily fit on screens of small devices such as "
+            u"phones and PDAs."
+        ),
+        required=False,
+    )
     form.widget(introduction=WysiwygFieldWidget)
 
     evaluation_optional = schema.Bool(
-            title=_("label_evaluation_optional",
-                default=u"Evaluation may be skipped"),
-            description=_("help_evaluation_optional",
-                default=u"This option allows users to skip the evaluation "
-                        u"phase."),
-            default=False,
-            required=False)
+        title=_("label_evaluation_optional", default=u"Evaluation may be skipped"),
+        description=_(
+            "help_evaluation_optional",
+            default=u"This option allows users to skip the evaluation " u"phase.",
+        ),
+        default=False,
+        required=False,
+    )
 
     language = schema.Choice(
-            title=_("label_language", default=u"Language"),
-            vocabulary="plone.app.vocabularies.AvailableContentLanguages",
-            default=u"en",
-            required=True)
+        title=_("label_language", default=u"Language"),
+        vocabulary="plone.app.vocabularies.AvailableContentLanguages",
+        default=u"en",
+        required=True,
+    )
 
     classification_code = schema.TextLine(
-            title=_("label_classification_code",
-                default=u"Classification code"),
-            description=_("help_classification_code",
-                default=u"A code identifying this sector. Classification "
-                        u"codes are defined by national standards bodies "
-                        u"and based on revision 2 of the NACE standard."),
-            required=False)
+        title=_("label_classification_code", default=u"Classification code"),
+        description=_(
+            "help_classification_code",
+            default=u"A code identifying this sector. Classification "
+            u"codes are defined by national standards bodies "
+            u"and based on revision 2 of the NACE standard.",
+        ),
+        required=False,
+    )
 
     tool_type = schema.Choice(
-        title=_(
-            "label_tool_type",
-            default=u"Type of OiRA Tool"),
+        title=_("label_tool_type", default=u"Type of OiRA Tool"),
         description=_(
             "description_tool_type",
-            default=u'This selection determines, which variant of an OiRA Tool'
-            u' will be created. If you are not sure, select "Classic".'),
+            default=u"This selection determines, which variant of an OiRA Tool"
+            u' will be created. If you are not sure, select "Classic".',
+        ),
         vocabulary="euphorie.tool_types_vocabulary",
         defaultFactory=get_tool_type_default,
-        required=True)
+        required=True,
+    )
+
+    measures_text_handling = schema.Choice(
+        title=_(
+            "measures_text_handling",
+            default=u"Handling of measures text (if measures-in-place are used)",
+        ),
+        description=_(
+            "description_measures_text_handling",
+            default=(
+                u"Defines how the “Measures in place” options are displayed "
+                u"to the user. "
+                u"Choose “Simple” if the texts for Description and General Approach "
+                u"are identical in your measures. "
+                u"Choose “Full” if the texts in General Approach "
+                u"provide more details than the Description."
+            ),
+        ),
+        vocabulary="euphorie.measures_text_handling_vocabulary",
+        default="full",
+        required=True,
+    )
+
+    integrated_action_plan = schema.Bool(
+        title=_("label_integrated_action_plan", default=u"Integrated Action Plan"),
+        description=_(
+            "description_integrated_action_plan",
+            default=u"If selected, the option to plan measures will be offered "
+            u"directly on the “Identification” page. There will be no separate "
+            u"“Action Plan” step in the navigation.",
+        ),
+        required=False,
+        default=False,
+    )
 
     enable_tool_notification = schema.Bool(
-        title=_("label_enable_tool_notification",
-                default=u"Show a custom notification for this OiRA tool?"),
+        title=_(
+            "label_enable_tool_notification",
+            default=u"Show a custom notification for this OiRA tool?",
+        ),
         description=_(
-            u'description_tool_notification',
-            default=u'If you enter text here, it will be shown to users '
-            u'in a pop-up when they open the tool. It can be used for '
-            u'notifying users about changes.'),
+            u"description_tool_notification",
+            default=u"If you enter text here, it will be shown to users "
+            u"in a pop-up when they open the tool. It can be used for "
+            u"notifying users about changes.",
+        ),
         required=False,
-        default=False)
+        default=False,
+    )
 
-    depends("tool_notification_title",
-            "enable_tool_notification",
-            "on")
+    depends("tool_notification_title", "enable_tool_notification", "on")
     tool_notification_title = ConditionalTextLine(
         title=_("label_tool_notification_title", default=u"Tool notification title"),
-        required=True)
+        required=True,
+    )
 
-    depends("tool_notification_message",
-            "enable_tool_notification",
-            "on")
+    depends("tool_notification_message", "enable_tool_notification", "on")
     tool_notification_message = ConditionalHtmlText(
-        title=_(
-            "label_tool_notification", default=u"Tool notification message"),
-        required=True)
+        title=_("label_tool_notification", default=u"Tool notification message"),
+        required=True,
+    )
     form.widget(tool_notification_message=WysiwygFieldWidget)
 
 
 class SurveyAttributeField(ParentAttributeField):
     parent_mapping = {
-            'survey_title': 'title',
-            'obsolete': 'obsolete',
+        "survey_title": "title",
+        "obsolete": "obsolete",
     }
 
 
@@ -155,19 +203,21 @@ def get_tool_type(context):
     the survey.
     """
     from euphorie.content.survey import ISurvey  # XXX Circular
+
     tt_default = get_tool_type_default()
     for parent in aq_chain(aq_inner(context)):
         if ISurvey.providedBy(parent):
-            return getattr(parent, 'tool_type', '') or tt_default
+            return getattr(parent, "tool_type", "") or tt_default
     return tt_default
 
 
-class Survey(dexterity.Container):
+class Survey(Container):
     """A risk assessment survey.
 
     A survey uses the *IIdGenerationRoot* behaviour to guarantee that
     all items inside the survey have a unique id.
     """
+
     grok.name("euphorie.container")
 
     implements(ISurvey, IQuestionContainer)
@@ -181,7 +231,7 @@ class Survey(dexterity.Container):
     def _get_id(self, orig_id):
         """Pick an id for pasted content."""
         frame = sys._getframe(1)
-        ob = frame.f_locals.get('ob')
+        ob = frame.f_locals.get("ob")
         if ob is not None and INameFromUniqueId.providedBy(ob):
             return get_next_id(self)
         return super(Survey, self)._get_id(orig_id)
@@ -206,14 +256,13 @@ class Survey(dexterity.Container):
 
     def hasNotification(self):
         """
-            Checks if a notification message was set
+        Checks if a notification message was set
         """
         return self.enable_tool_notification or False
 
     def ProfileQuestions(self):
         """Return a list of all profile questions."""
-        return [child for child in self.values()
-                if IProfileQuestion.providedBy(child)]
+        return [child for child in self.values() if IProfileQuestion.providedBy(child)]
 
     def get_tool_type_name(self):
         """ Returns the human readable name of the chosen tool type """
@@ -227,10 +276,14 @@ class Survey(dexterity.Container):
 
 @indexer(ISurvey)
 def SearchableTextIndexer(obj):
-    return " ".join([obj.title,
-                     StripMarkup(obj.description),
-                     StripMarkup(obj.introduction),
-                     obj.classification_code or u""])
+    return " ".join(
+        [
+            obj.title,
+            StripMarkup(obj.description),
+            StripMarkup(obj.introduction),
+            obj.classification_code or u"",
+        ]
+    )
 
 
 class View(grok.View, DragDropHelper):
@@ -241,47 +294,53 @@ class View(grok.View, DragDropHelper):
     grok.name("nuplone-view")
 
     def _morph(self, child):
-        state = getMultiAdapter((child, self.request),
-                name="plone_context_state")
-        return {'id': child.id,
-                'title': child.title,
-                'url': state.view_url()}
+        state = getMultiAdapter((child, self.request), name="plone_context_state")
+        return {"id": child.id, "title": child.title, "url": state.view_url()}
 
     def update(self):
-        self.children = [self._morph(child)
-                         for child in self.context.values()
-                         if IModule.providedBy(child) or
-                             IProfileQuestion.providedBy(child)]
+        self.children = [
+            self._morph(child)
+            for child in self.context.values()
+            if IModule.providedBy(child) or IProfileQuestion.providedBy(child)
+        ]
         self.group = aq_parent(aq_inner(self.context))
         super(View, self).update()
 
 
 class ISurveyAddSchema(form.Schema):
     title = schema.TextLine(
-            title=_("label_survey_title", default=u"Version name"),
-            description=_("help_survey_title",
-                default=u"This is the title of this OiRA Tool version. This "
-                        u"name is never shown to users."),
-            required=True)
+        title=_("label_survey_title", default=u"Version name"),
+        description=_(
+            "help_survey_title",
+            default=u"This is the title of this OiRA Tool version. This "
+            u"name is never shown to users.",
+        ),
+        required=True,
+    )
 
 
 class ISurveyEditSchema(ISurvey):
     survey_title = schema.TextLine(
-            title=_("label_title", default=u"Title"),
-            description=_("help_surveygroup_title",
-                default=u"The title of this OiRA Tool. This title is used in "
-                        u"the OiRA Tool overview in the clients."),
-            required=True)
+        title=_("label_title", default=u"Title"),
+        description=_(
+            "help_surveygroup_title",
+            default=u"The title of this OiRA Tool. This title is used in "
+            u"the OiRA Tool overview in the clients.",
+        ),
+        required=True,
+    )
     form.order_before(survey_title="*")
 
     obsolete = schema.Bool(
-            title=_("label_survey_obsolete",
-                default=u"Obsolete OiRA tool"),
-            description=_("help_survey_obsolete",
-                default=u"This OiRA Tool is obsolete; it has been retired or "
-                        u"replaced with another OiRA Tool."),
-            default=False,
-            required=False)
+        title=_("label_survey_obsolete", default=u"Obsolete OiRA tool"),
+        description=_(
+            "help_survey_obsolete",
+            default=u"This OiRA Tool is obsolete; it has been retired or "
+            u"replaced with another OiRA Tool.",
+        ),
+        default=False,
+        required=False,
+    )
     form.order_before(obsolete="introduction")
 
 
@@ -292,6 +351,7 @@ class AddForm(dexterity.AddForm):
     vocabulary factories always get a None context. See
     http://code.google.com/p/dexterity/issues/detail?id=125
     """
+
     grok.context(ISurvey)
     grok.name("euphorie.survey")
     grok.require("euphorie.content.AddNewRIEContent")
@@ -300,10 +360,11 @@ class AddForm(dexterity.AddForm):
     template = ViewPageTemplateFile("templates/survey_add.pt")
 
     def surveys(self):
-        templates = [{'id': survey.id,
-                      'title': survey.title}
-                     for survey in self.context.values()
-                     if ISurvey.providedBy(survey)]
+        templates = [
+            {"id": survey.id, "title": survey.title}
+            for survey in self.context.values()
+            if ISurvey.providedBy(survey)
+        ]
         return templates
 
     def copyTemplate(self, source, title):
@@ -345,26 +406,42 @@ class Edit(form.SchemaEditForm):
         changes = super(Edit, self).applyChanges(data)
         if changes:
             # Reindex our parents title.
-            catalog = getToolByName(self.context, 'portal_catalog')
+            catalog = getToolByName(self.context, "portal_catalog")
             catalog.indexObject(aq_parent(aq_inner(self.context)))
         return changes
 
+    def updateWidgets(self):
+        super(Edit, self).updateWidgets()
+        appconfig = getUtility(IAppConfig)
+        settings = appconfig.get("euphorie")
+        if not settings.get("use_integrated_action_plan", False):
+            self.widgets["integrated_action_plan"].mode = "hidden"
+
 
 class Delete(actions.Delete):
     """Special delete action class which prevents deletion of published surveys
     or of the last survey in a group.
     """
+
     grok.context(ISurvey)
 
     def verify(self, container, context):
         flash = IStatusMessage(self.request).addStatusMessage
 
-        if hasattr(aq_base(container), 'published') and \
-                container.published == context.id:
-            flash(_("message_no_delete_published_survey",
-                    default=u"You cannot delete an OiRA Tool version that is published. "
-                            u"Please unpublish it first."),
-                    "error")
+        if (
+            hasattr(aq_base(container), "published")
+            and container.published == context.id
+        ):
+            flash(
+                _(
+                    "message_no_delete_published_survey",
+                    default=(
+                        u"You cannot delete an OiRA Tool version that is published. "
+                        u"Please unpublish it first."
+                    ),
+                ),
+                "error",
+            )
             self.request.response.redirect(context.absolute_url())
             return False
 
@@ -376,11 +453,15 @@ class Delete(actions.Delete):
         if count > 1:
             return True
         else:
-            flash(_("message_delete_no_last_survey",
+            flash(
+                _(
+                    "message_delete_no_last_survey",
                     default=u"This is the only version of the OiRA Tool and can "
-                        u"therefore not be deleted. Did you perhaps want to "
-                        u"remove the OiRA Tool itself?"),
-                    "error")
+                    u"therefore not be deleted. Did you perhaps want to "
+                    u"remove the OiRA Tool itself?",
+                ),
+                "error",
+            )
             self.request.response.redirect(context.absolute_url())
             return False
 
