@@ -13,7 +13,6 @@ from zope.component import getMultiAdapter
 
 
 class SectorTests(EuphorieIntegrationTestCase):
-
     def _create(self, container, *args, **kwargs):
         newid = container.invokeFactory(*args, **kwargs)
         return getattr(container, newid)
@@ -41,22 +40,21 @@ class SectorTests(EuphorieIntegrationTestCase):
         addSurvey(sector, EMPTY_SURVEY)
         surveygroup = sector["test-survey"]
         self.assertEqual(surveygroup.published, None)
-        deleteaction = getMultiAdapter((sector, sector.REQUEST), name='delete')
+        deleteaction = getMultiAdapter((sector, sector.REQUEST), name="delete")
         self.assertEqual(deleteaction.verify(sector.aq_parent, sector), True)
 
     def testDeleteWithPublishedSurvey(self):
         sector = createSector(self.portal)
         survey = addSurvey(sector, EMPTY_SURVEY)
         surveygroup = sector["test-survey"]
-        publishview = getMultiAdapter((survey, survey.REQUEST), name='publish')
+        publishview = getMultiAdapter((survey, survey.REQUEST), name="publish")
         publishview.publish()
         self.assertEqual(surveygroup.published, "standard-version")
-        deleteaction = getMultiAdapter((sector, sector.REQUEST), name='delete')
+        deleteaction = getMultiAdapter((sector, sector.REQUEST), name="delete")
         self.assertEqual(deleteaction.verify(sector.aq_parent, sector), False)
 
 
 class SectorAsUserTests(EuphorieIntegrationTestCase):
-
     def _create(self, container, *args, **kwargs):
         newid = container.invokeFactory(*args, **kwargs)
         return getattr(container, newid)
@@ -102,58 +100,41 @@ class SectorAsUserTests(EuphorieIntegrationTestCase):
         sector.title = u"This is a sector"
         pas = self.portal.acl_users
         auth = UserAuthentication(sector)
-        self.assertEqual(
-            auth.authenticateCredentials(dict(password="s3cr3t")), None
-        )
+        self.assertEqual(auth.authenticateCredentials(dict(password="s3cr3t")), None)
         pas.userSetPassword(auth.getUserId(), "s3cr3t")
         self.assertEqual(
             auth.authenticateCredentials(dict(password="s3cr3t")),
-            (auth.getUserId(), auth.getUserName())
+            (auth.getUserId(), auth.getUserName()),
         )
 
 
 class SectorBrowserTests(EuphorieFunctionalTestCase):
-
     def testDuplicateLoginNotAllowed(self):
         # Test for http://code.simplon.biz/tracker/euphorie/ticket/152
         createSector(self.portal, login="sector")
         browser = self.get_browser(logged_in=True)
-        browser.open(
-            "%s/sectors/nl/@@manage-users" % self.portal.absolute_url()
-        )
+        browser.open("%s/sectors/nl/@@manage-users" % self.portal.absolute_url())
         browser.getLink("Add new sector").click()
         browser.getControl(name="form.widgets.title").value = "New sector"
         browser.getControl(name="form.widgets.login").value = "sector"
         browser.getControl(name="form.widgets.password").value = "secret"
-        browser.getControl(
-            name="form.widgets.password.confirm"
-        ).value = "secret"
+        browser.getControl(name="form.widgets.password.confirm").value = "secret"
         browser.getControl(name="form.widgets.contact_name").value = "John Doe"
-        browser.getControl(
-            name="form.widgets.contact_email"
-        ).value = "john@example.com"
+        browser.getControl(name="form.widgets.contact_email").value = "john@example.com"
         browser.getControl(name="form.buttons.save").click()
         self.assertTrue("This login name is already taken" in browser.contents)
 
     def testPasswordPolicy(self):
         createSector(self.portal, login="sector")
         browser = self.get_browser(logged_in=True)
-        browser.open(
-            "%s/sectors/nl/@@manage-users" % self.portal.absolute_url()
-        )
+        browser.open("%s/sectors/nl/@@manage-users" % self.portal.absolute_url())
         browser.getLink("Add new sector").click()
         browser.getControl(name="form.widgets.title").value = "New sector"
         browser.getControl(name="form.widgets.login").value = "sector"
         browser.getControl(name="form.widgets.password").value = "secret"
-        browser.getControl(
-            name="form.widgets.password.confirm"
-        ).value = "secret"
-        browser.getControl(
-            name="form.widgets.contact_name"
-        ).value = "Max Mustermann"
-        browser.getControl(
-            name="form.widgets.contact_email"
-        ).value = "max@example.com"
+        browser.getControl(name="form.widgets.password.confirm").value = "secret"
+        browser.getControl(name="form.widgets.contact_name").value = "Max Mustermann"
+        browser.getControl(name="form.widgets.contact_email").value = "max@example.com"
         browser.getControl(name="form.buttons.save").click()
         self.assertTrue(
             u"Your password must contain at least 5 characters, "
@@ -163,7 +144,6 @@ class SectorBrowserTests(EuphorieFunctionalTestCase):
 
 
 class PermissionTests(EuphorieIntegrationTestCase):
-
     def _create(self, container, *args, **kwargs):
         newid = container.invokeFactory(*args, **kwargs)
         return getattr(container, newid)
@@ -179,19 +159,15 @@ class PermissionTests(EuphorieIntegrationTestCase):
         with api.env.adopt_user(TEST_USER_NAME):
             sector = self.createSector()
         wt = self.portal.portal_workflow
-        self.assertEqual(wt.getChainFor(sector), ("sector", ))
+        self.assertEqual(wt.getChainFor(sector), ("sector",))
         self.assertEqual(wt.getInfoFor(sector, "review_state"), "hidden")
 
     def testAnonymous(self):
         with api.env.adopt_user(TEST_USER_NAME):
             sector = self.createSector()
         self.logout()
-        self.assertTrue(
-            not _checkPermission("Euphorie: Add new RIE Content", sector)
-        )
-        self.assertTrue(
-            not _checkPermission("Access contents information", sector)
-        )
+        self.assertTrue(not _checkPermission("Euphorie: Add new RIE Content", sector))
+        self.assertTrue(not _checkPermission("Access contents information", sector))
         self.assertFalse(_checkPermission("Modify portal content", sector))
         self.assertFalse(_checkPermission("View", sector))
 
@@ -209,16 +185,10 @@ class PermissionTests(EuphorieIntegrationTestCase):
     def testCountryManager(self):
         with api.env.adopt_user(TEST_USER_NAME):
             sector = self.createSector()
-        self.portal.acl_users._doAddUser(
-            "support", "secret", ["CountryManager"], []
-        )
+        self.portal.acl_users._doAddUser("support", "secret", ["CountryManager"], [])
         self.login("support")
-        self.assertTrue(
-            _checkPermission("Euphorie: Add new RIE Content", sector)
-        )
-        self.assertTrue(
-            _checkPermission("Access contents information", sector)
-        )
+        self.assertTrue(_checkPermission("Euphorie: Add new RIE Content", sector))
+        self.assertTrue(_checkPermission("Access contents information", sector))
         self.assertTrue(_checkPermission("Modify portal content", sector))
         self.assertTrue(_checkPermission("View", sector))
 
@@ -227,18 +197,13 @@ class PermissionTests(EuphorieIntegrationTestCase):
             sector = self.createSector()
         self.portal.acl_users._doAddUser("manager", "secret", ["Manager"], [])
         self.login("manager")
-        self.assertTrue(
-            _checkPermission("Euphorie: Add new RIE Content", sector)
-        )
-        self.assertTrue(
-            _checkPermission("Access contents information", sector)
-        )
+        self.assertTrue(_checkPermission("Euphorie: Add new RIE Content", sector))
+        self.assertTrue(_checkPermission("Access contents information", sector))
         self.assertTrue(_checkPermission("Modify portal content", sector))
         self.assertTrue(_checkPermission("View", sector))
 
 
 class GetSurveysTests(EuphorieIntegrationTestCase):
-
     def getSurveys(self, context):
         return getSurveys(context)
 
@@ -249,23 +214,28 @@ class GetSurveysTests(EuphorieIntegrationTestCase):
         sector = createSector(self.portal)
         survey = addSurvey(sector, EMPTY_SURVEY)
         self.assertEqual(
-            self.getSurveys(survey), [{
-                "url": "http://nohost/plone/sectors/nl/sector/test-survey",
-                "published": False,
-                "id": "test-survey",
-                "title": u"Test survey",
-                "surveys": [{
-                    "id": "standard-version",
-                    "title": u"Standard version",
-                    "current": True,
-                    "url": "http://nohost/plone/sectors/nl/sector/"
-                    "test-survey/standard-version",
-                    "versions": [],
-                    "modified": False,
+            self.getSurveys(survey),
+            [
+                {
+                    "url": "http://nohost/plone/sectors/nl/sector/test-survey",
                     "published": False,
-                    "publication_date": None,
-                }],
-            }]
+                    "id": "test-survey",
+                    "title": u"Test survey",
+                    "surveys": [
+                        {
+                            "id": "standard-version",
+                            "title": u"Standard version",
+                            "current": True,
+                            "url": "http://nohost/plone/sectors/nl/sector/"
+                            "test-survey/standard-version",
+                            "versions": [],
+                            "modified": False,
+                            "published": False,
+                            "publication_date": None,
+                        }
+                    ],
+                }
+            ],
         )
 
     def testTwoUnpublishedSurveysgroups(self):
