@@ -51,8 +51,7 @@ RE_LOGIN = re.compile(r"^[a-z][a-z0-9-]+$")
 
 
 class DuplicateLoginError(ValidationError):
-    __doc__ = _("error_existing_login",
-            default=u"This login name is already taken.")
+    __doc__ = _("error_existing_login", default=u"This login name is already taken.")
 
 
 class InvalidPasswordError(ValidationError):
@@ -66,9 +65,13 @@ class InvalidPasswordError(ValidationError):
 
 def validLoginValue(value):
     if not RE_LOGIN.match(value):
-        raise Invalid(_("error_invalid_login",
-            default=u"A login name may only consist of lowercase letters "
-                    u"and numbers."))
+        raise Invalid(
+            _(
+                "error_invalid_login",
+                default=u"A login name may only consist of lowercase letters "
+                u"and numbers.",
+            )
+        )
     return True
 
 
@@ -77,33 +80,32 @@ class LoginField(schema.TextLine):
 
 
 class IUser(form.Schema):
-    title = schema.TextLine(
-            title=_("label_user_title", default=u"Name"),
-            required=True)
+    title = schema.TextLine(title=_("label_user_title", default=u"Name"), required=True)
 
     contact_email = schema.TextLine(
-            title=_("label_contact_email", default=u"Contact email address"),
-            required=True)
+        title=_("label_contact_email", default=u"Contact email address"), required=True
+    )
 
     login = LoginField(
-            title=_("label_login_name", default=u"Login name"),
-            required=True,
-            constraint=validLoginValue)
+        title=_("label_login_name", default=u"Login name"),
+        required=True,
+        constraint=validLoginValue,
+    )
     dexterity.write_permission(login="euphorie.content.ManageCountry")
 
     password = schema.Password(
-            title=_("label_password", default=u"Password"),
-            required=True)
+        title=_("label_password", default=u"Password"), required=True
+    )
 
     locked = schema.Bool(
-            title=_("label_account_locked", default=u"Account is locked"),
-            required=False,
-            default=False)
+        title=_("label_account_locked", default=u"Account is locked"),
+        required=False,
+        default=False,
+    )
     dexterity.write_permission(locked="euphorie.content.ManageCountry")
 
 
 class BaseValidator(SimpleFieldValidator):
-
     def __init__(self, context, request, view, field, widget):
         self.context = context
         self.request = request
@@ -111,12 +113,13 @@ class BaseValidator(SimpleFieldValidator):
         self.field = field
         self.widget = widget
 
+
 class UniqueLoginValidator(grok.MultiAdapter, BaseValidator):
     grok.implements(IValidator)
     grok.adapts(Interface, Interface, IAddForm, LoginField, Interface)
 
     def validate(self, value):
-        """ Ensure that there isn't already a user id isn't already in use.
+        """Ensure that there isn't already a user id isn't already in use.
 
         :raises: DuplicateLoginError
         """
@@ -130,17 +133,19 @@ class UniqueLoginValidator(grok.MultiAdapter, BaseValidator):
 
 class PasswordValidator(grok.MultiAdapter, PasswordConfirmationValidator):
     grok.implements(IValidator)
-    grok.adapts(Interface, Interface, IForm, schema.Password, IPasswordConfirmationWidget)
+    grok.adapts(
+        Interface, Interface, IForm, schema.Password, IPasswordConfirmationWidget
+    )
 
     def validate(self, value):
-        """ Ensure that the password complies with the policy configured in
+        """Ensure that the password complies with the policy configured in
         portal_registration.
 
         :raises: InvalidPasswordError
         """
         super(PasswordValidator, self).validate(value)
-        regtool = api.portal.get_tool('portal_registration')
-        err = regtool.pasValidation('password', value)
+        regtool = api.portal.get_tool("portal_registration")
+        err = regtool.pasValidation("password", value)
         if err:
             raise InvalidPasswordError(value, err)
 
@@ -158,6 +163,7 @@ class UserProvider(object):
     interface provided by an adapter if it provides multiple interfaces, even
     if they are derived classes).
     """
+
     adapts(IUser)
 
     def __init__(self, context):
@@ -181,16 +187,19 @@ class UserAuthentication(grok.Adapter, UserProvider):
     :obj:`Products.membrane.interfaces.user.IMembraneUserAuth` interface. This
     interface is responsible for the authentication logic of accounts.
     """
+
     grok.context(IUser)
     grok.implements(membrane.IMembraneUserAuth)
 
     def authenticateCredentials(self, credentials):
         if self.context.locked:
             IStatusMessage(self.context.REQUEST).add(
-                _("message_user_locked",
-                default=u'Account "${title}" has been locked.',
-                mapping=dict(title=self.context.title)
-                ), "warn"
+                _(
+                    "message_user_locked",
+                    default=u'Account "${title}" has been locked.',
+                    mapping=dict(title=self.context.title),
+                ),
+                "warn",
             )
             return None
         candidate = credentials.get("password", None)
@@ -198,12 +207,14 @@ class UserAuthentication(grok.Adapter, UserProvider):
         if candidate is None or real is None:
             return None
         conf = getUtility(IAppConfig).get("euphorie", {})
-        max_attempts = int(conf.get('max_login_attempts', '0').strip())
+        max_attempts = int(conf.get("max_login_attempts", "0").strip())
 
-        if candidate == real: # XXX: Plain passwords should be deprecated
-            log.warn("Passwords should not be stored unhashed. Please run "
+        if candidate == real:  # XXX: Plain passwords should be deprecated
+            log.warn(
+                "Passwords should not be stored unhashed. Please run "
                 "the upgrade step to make sure all plaintext passwords are "
-                "hashed.")
+                "hashed."
+            )
             self.context._v_login_attempts = 0
             return (self.getUserId(), self.getUserName())
 
@@ -215,26 +226,32 @@ class UserAuthentication(grok.Adapter, UserProvider):
     def applyLockoutPolicy(self, max_attempts):
         if not max_attempts:
             return
-        if not hasattr(aq_base(self.context), '_v_login_attempts'):
+        if not hasattr(aq_base(self.context), "_v_login_attempts"):
             self.context._v_login_attempts = 0
         self.context._v_login_attempts += 1
 
         if self.context._v_login_attempts < max_attempts:
             IStatusMessage(self.context.REQUEST).add(
-                _("message_lock_warn",
-                    default=u"Please be aware that you have %s more login " \
-                            u"attempts before your account will be locked." \
-                            % (max_attempts-self.context._v_login_attempts),
-                ), "warn"
+                _(
+                    "message_lock_warn",
+                    default=u"Please be aware that you have %s more login "
+                    u"attempts before your account will be locked."
+                    % (max_attempts - self.context._v_login_attempts),
+                ),
+                "warn",
             )
         else:
-            log.warn("Account locked for %s, due to more than %s unsuccessful "
-                    "login attempts" % (self.getUserName(), max_attempts))
+            log.warn(
+                "Account locked for %s, due to more than %s unsuccessful "
+                "login attempts" % (self.getUserName(), max_attempts)
+            )
             IStatusMessage(self.context.REQUEST).add(
-                _("message_user_locked",
-                default=u'Account "${title}" has been locked.',
-                mapping=dict(title=self.context.title)
-                ), "warn"
+                _(
+                    "message_user_locked",
+                    default=u'Account "${title}" has been locked.',
+                    mapping=dict(title=self.context.title),
+                ),
+                "warn",
             )
             self.context.locked = True
 
@@ -246,6 +263,7 @@ class UserChanger(grok.Adapter, UserProvider):
     :obj:`Products.membrane.interfaces.user.IMembraneUserChanger` interface.
     This interface is responsible for changing a users password.
     """
+
     grok.context(IUser)
     grok.implements(membrane.IMembraneUserChanger)
 
@@ -263,15 +281,13 @@ class UserChanger(grok.Adapter, UserProvider):
 
 
 class PasswordDataManager(AttributeField, grok.MultiAdapter):
-    """ Hash passwords before storing them
-    """
+    """Hash passwords before storing them"""
+
     grok.implements(IDataManager)
     grok.adapts(IUser, schema.interfaces.IPassword)
 
     def set(self, value):
-        super(PasswordDataManager, self).set(
-            bcrypt.hashpw(value, bcrypt.gensalt())
-        )
+        super(PasswordDataManager, self).set(bcrypt.hashpw(value, bcrypt.gensalt()))
 
 
 class UserProperties(grok.Adapter, UserProvider):
@@ -286,12 +302,12 @@ class UserProperties(grok.Adapter, UserProvider):
     interface. As a result all methods take a `user` parameter, which should
     always be the same as the adapted object for membrane adapters.
     """
+
     grok.context(IUser)
     grok.implements(membrane.IMembraneUserProperties)
 
     # A mapping for IUser properties to Plone user properties
-    property_map = [("title", "fullname"),
-                    ("contact_email", "email")]
+    property_map = [("title", "fullname"), ("contact_email", "email")]
 
     def getPropertiesForUser(self, user, request=None):
         properties = {}
@@ -316,10 +332,11 @@ class UserProperties(grok.Adapter, UserProvider):
 
 
 class Lock(grok.View):
-    """ Lock or unlock a User account.
+    """Lock or unlock a User account.
 
     View name: @@lock
     """
+
     grok.context(IUser)
     grok.require("euphorie.content.ManageCountry")
     grok.layer(NuPloneSkin)
@@ -328,23 +345,32 @@ class Lock(grok.View):
     def render(self):
         if self.request.method != "POST":
             raise Unauthorized
-        authenticator = getMultiAdapter((self.context, self.request),
-                name=u"authenticator")
+        authenticator = getMultiAdapter(
+            (self.context, self.request), name=u"authenticator"
+        )
         if not authenticator.verify():
             raise Unauthorized
 
-        self.context.locked = locked = \
-                (self.request.form.get("action", "lock") == "lock")
+        self.context.locked = locked = self.request.form.get("action", "lock") == "lock"
         flash = IStatusMessage(self.request).addStatusMessage
         if locked:
-            flash(_("message_user_locked",
+            flash(
+                _(
+                    "message_user_locked",
                     default=u'Account "${title}" has been locked.',
-                    mapping=dict(title=self.context.title)), "success")
+                    mapping=dict(title=self.context.title),
+                ),
+                "success",
+            )
         else:
-            flash(_("message_user_unlocked",
+            flash(
+                _(
+                    "message_user_unlocked",
                     default=u'Account "${title}" has been unlocked.',
-                    mapping=dict(title=self.context.title)), "success")
+                    mapping=dict(title=self.context.title),
+                ),
+                "success",
+            )
 
         country = aq_parent(aq_inner(self.context))
-        self.request.response.redirect(
-                "%s/@@manage-users" % country.absolute_url())
+        self.request.response.redirect("%s/@@manage-users" % country.absolute_url())
