@@ -6,4 +6,4 @@ def setCountryLanguageFR(context):
     portal = api.portal.get()
     client = portal.client
     country = client.fr
-    setattr(country, 'language', 'fr')
+    setattr(country, "language", "fr")
